##  Contribute Data to Fact Sheets
To input or update information on a Fact Sheet, go to the Inventory and open the relevant Fact Sheet. At the top of a Fact Sheet, you will find a header displaying key details such as name, type, tags, and description. Below this header, there are several tabs: Fact Sheet, Subscriptions, Comments, To-Dos, Resources, etc., to document and manage diverse information.
The attributes and information you find in Fact Sheets depend on the type of Fact Sheet. To edit or add any information, do the following:
  1. Hover over the section you wish to edit.
  2. On the right side corner of the section, you will find buttons for Edit or Add.
  3. Click on the relevant button and provide your input.
  4. Click Save at the end.


To learn more on how to add or edit data in a fact sheet, see [Adding and Editing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Users with the appropriate permissions can add and edit data in fact sheets, while administrators can customize and manage these permissions. By switching to table view in the inventory, you can perform inline editing across multiple fact sheets, and using the import option, you can update multiple fact sheets in bulk.").
![Adding data to Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27454f717a441014905d9f9c42d75f7c_LowRes.gif)
Adding data to Fact Sheet
Depending on your role, certain Fact Sheets are more relevant to you than others. For instance, Application Owners focus on Application Fact Sheets, Business Owners typically handle Business Capability Fact Sheets, and Transformation and Project Managers concentrate on Initiative and Project Fact Sheets. Similarly, Data Architects contribute to Data Object Fact Sheets, and so forth.
### Example: Filling an Application Fact Sheet
In the Application Fact sheet, essential attributes include Name, Lifecycle information, Functional fit, Technical fit, the Business Capabilities it is supporting, Business Criticality, the IT components it is relying on, etc.
The video below provides a quick overview of how to complete the Application Fact Sheet and offers best practices to help you understand the attributes and make informed choices:
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_1ond8bpx/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Ffor-application-and-business-owners%3Fversion%3DCLOUD)
